@@ -9,19 +9,19 @@
 #         tkman a.out.5
 #
 
-proc tkman {man} {
+proc TkMan {man} {
 
    if {[set found [lsearch [winfo interps] tkman*]]==-1} {
       # if TkMan doesn't already exist, start one up
       if {[catch {exec tkman &}]} {puts stdout "tkman not found"; return}
 
       # wait for it to be registered
-      for {set found -1} {$found==-1} {after 1} {
+      for {set found -1} {$found==-1} {after 200} {
          set found [lsearch [winfo interps] tkman*]
       }
 
       # wait for it to initialize
-      for {set ready 0} {!$ready} {after 1} {
+      for {set ready 0} {!$ready} {after 200} {
          catch {if {[send tkman set manx(init)]=="1"} {set ready 1}}
       }
    }
@@ -30,7 +30,6 @@ proc tkman {man} {
    # .man is the main window, guaranteed to exist
    set w .man
    send $tkman raise $w
-
    send $tkman manShowMan $man
 
    return
